// THIS FILE IS GENERATED. ONE SHOULD NOT MODIFY IT
//! This module provides terms for `XKOS: an SKOS extension for representing statistical classifications` vocabulary
//!
//! This module requires `ns-xkos` feature to be enabled.
//!
//! ## Vocabulary:
//!
//! |||
//! |-----|-----|
//! |**Title**|XKOS: an SKOS extension for representing statistical classifications|
//! |**Prefix**|xkos|
//! |**Namespace base IRI**|<http://rdf-vocabulary.ddialliance.org/xkos#>|
//! |**Description**|This ontology is based on work initiated at Dagstuhl Schloss in September 2011|
//! |**Is defined by**|<https://raw.githubusercontent.com/linked-statistics/xkos/master/xkos.ttl>|
//!

use crate::namespace;

namespace!(
    "http://rdf-vocabulary.ddialliance.org/xkos#",;
    /// ``: 
    NAMESPACE_BASE, "",
    /// `Classification level`: 
    ClassificationLevel, "ClassificationLevel",
    /// `Concept association`: 
    ConceptAssociation, "ConceptAssociation",
    /// `Correspondence`: 
    Correspondence, "Correspondence",
    /// `Explanatory note`: 
    ExplanatoryNote, "ExplanatoryNote",
    /// `additional content`: 
    additionalContentNote, "additionalContentNote",
    /// `after`: 
    after, "after",
    /// `before`: 
    before, "before",
    /// `belongs to`: 
    belongsTo, "belongsTo",
    /// `case law`: 
    caseLaw, "caseLaw",
    /// `has causal`: 
    causal, "causal",
    /// `caused by`: 
    causedBy, "causedBy",
    /// `causes`: 
    causes, "causes",
    /// `classified under`: 
    classifiedUnder, "classifiedUnder",
    /// `compares`: 
    compares, "compares",
    /// `core content`: 
    coreContentNote, "coreContentNote",
    /// `covers`: 
    covers, "covers",
    /// `covers exhaustively`: 
    coversExhaustively, "coversExhaustively",
    /// `covers mutually exclusively`: 
    coversMutuallyExclusively, "coversMutuallyExclusively",
    /// `depth`: 
    depth, "depth",
    /// `disjoint from`: 
    disjoint, "disjoint",
    /// `exclusions`: 
    exclusionNote, "exclusionNote",
    /// `follows`: 
    follows, "follows",
    /// `generalizes`: 
    generalizes, "generalizes",
    /// `has part`: 
    hasPart, "hasPart",
    /// `inclusions`: 
    inclusionNote, "inclusionNote",
    /// `is a part of`: 
    isPartOf, "isPartOf",
    /// `level list`: 
    levels, "levels",
    /// `made of`: 
    madeOf, "madeOf",
    /// `maximum length`: 
    maxLength, "maxLength",
    /// `next`: immediate successor in the sequence
    next, "next",
    /// `code pattern`: 
    notationPattern, "notationPattern",
    /// `number of levels`: 
    numberOfLevels, "numberOfLevels",
    /// `organized by`: 
    organizedBy, "organizedBy",
    /// `plain text`: This property is expected to store plain text literals, without HTML or XML markup.
    plainText, "plainText",
    /// `precedes`: predecessor in the sequence
    precedes, "precedes",
    /// `previous`: immediate predecessor in the sequence
    previous, "previous",
    /// `has sequential`: 
    sequential, "sequential",
    /// `source concept`: 
    sourceConcept, "sourceConcept",
    /// `specializes`: 
    specializes, "specializes",
    /// `succeeds`: successor in the sequence
    succeeds, "succeeds",
    /// `supersedes`: 
    supersedes, "supersedes",
    /// `target concept`: 
    targetConcept, "targetConcept",
    /// `has temporal`: 
    temporal, "temporal",
    /// `variant`: 
    variant, "variant"
);
